==> blancoMessage-0.4.0-src.zip: blancoMessage/blanco.python/main/blanco/message/message/BlancoMessageMessage.py <==
# -*- coding: cp932 -*-
"""̃\[XR[h blanco FrameworkɂĎĂ܂B
"""
class BlancoMessageMessage:
    """blancoMessageIɗp郁bZ[WNXłB
    """

    """[bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]

    No.2:
    """
    MBMSGI01 = '[MBMSGI01] bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B'

    """[T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]

    No.3:
    """
    MBMSGI02 = '[MBMSGI02] T|[gȂo̓vO~Oꏈn[{0}]w肳܂B'

    """[bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]

    No.4:
    """
    MBMSGI03 = '[MBMSGI03] bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B'

    """[bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]

    No.5:
    """
    MBMSGI04 = '[MBMSGI04] bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB'

    """[^fBNg[{0}]݂܂B]

    No.8:
    """
    MBMSGA01 = '[MBMSGA01] ^fBNg[{0}]݂܂B'

    def getMbmsgi01(self, arg0):
        """bZ[W`ID[BlancoMessage]AL[[MBMSGI01]̕擾܂B

        No.2:
        [bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMbmsgi01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return '[MBMSGI01] bZ[W`ID[' + arg0 + ']̃pbP[Ww肳Ă܂B'
    #end

    def getMbmsgi02(self, arg0):
        """bZ[W`ID[BlancoMessage]AL[[MBMSGI02]̕擾܂B

        No.3:
        [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMbmsgi02]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return '[MBMSGI02] T|[gȂo̓vO~Oꏈn[' + arg0 + ']w肳܂B'
    #end

    def getMbmsgi03(self, arg0, arg1):
        """bZ[W`ID[BlancoMessage]AL[[MBMSGI03]̕擾܂B

        No.4:
        [bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        arg1 -- u{1}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMbmsgi03]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg1 is None:
            raise ValueError, "\bh[getMbmsgi03]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return '[MBMSGI03] bZ[W`ID[' + arg0 + ']ɂāAL[[' + arg1 + ']2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B'
    #end

    def getMbmsgi04(self, arg0, arg1, arg2, arg3):
        """bZ[W`ID[BlancoMessage]AL[[MBMSGI04]̕擾܂B

        No.5:
        [bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        arg1 -- u{1}̒lB
        arg2 -- u{2}̒lB
        arg3 -- u{3}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMbmsgi04]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg1 is None:
            raise ValueError, "\bh[getMbmsgi04]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg2 is None:
            raise ValueError, "\bh[getMbmsgi04]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg3 is None:
            raise ValueError, "\bh[getMbmsgi04]̃p[^[arg3]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return '[MBMSGI04] bZ[W`ID[' + arg0 + ']ɂāAL[[' + arg1 + ']̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[' + arg2 + ']ƃ\[XohƂĔfꍇ̒ǔ[' + arg3 + ']ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB'
    #end

    def getMbmsga01(self, arg0):
        """bZ[W`ID[BlancoMessage]AL[[MBMSGA01]̕擾܂B

        No.8:
        [^fBNg[{0}]݂܂B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMbmsga01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return '[MBMSGA01] ^fBNg[' + arg0 + ']݂܂B'
    #end
#end

==> blancoMessage-0.5.7-src.zip: blancoMessage/blanco.python/main/blanco/message/message/BlancoMessageMessage.py <==
# -*- coding: cp932 -*-
"""̃\[XR[h blanco FrameworkɂĎĂ܂B
"""
class BlancoMessageMessage:
    """blancoMessageIɗp郁bZ[WNXłB
    """

    """[bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]

    No.2:
    """
    MBMSGI01 = '[MBMSGI01] bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B'

    """L[l: KEY_MBMSGI01

    No.2:
    """
    KEY_MBMSGI01 = 'MBMSGI01'

    """[T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]

    No.3:
    """
    MBMSGI02 = '[MBMSGI02] T|[gȂo̓vO~Oꏈn[{0}]w肳܂B'

    """L[l: KEY_MBMSGI02

    No.3:
    """
    KEY_MBMSGI02 = 'MBMSGI02'

    """[bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]

    No.4:
    """
    MBMSGI03 = '[MBMSGI03] bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B'

    """L[l: KEY_MBMSGI03

    No.4:
    """
    KEY_MBMSGI03 = 'MBMSGI03'

    """[bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]

    No.5:
    """
    MBMSGI04 = '[MBMSGI04] bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB'

    """L[l: KEY_MBMSGI04

    No.5:
    """
    KEY_MBMSGI04 = 'MBMSGI04'

    """[^fBNg[{0}]݂܂B]

    No.8:
    """
    MBMSGA01 = '[MBMSGA01] ^fBNg[{0}]݂܂B'

    """L[l: KEY_MBMSGA01

    No.8:
    """
    KEY_MBMSGA01 = 'MBMSGA01'

    def getMbmsgi01(self, arg0):
        """bZ[W`ID[BlancoMessage]AL[[MBMSGI01]̕擾܂B

        No.2:
        [bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMbmsgi01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return '[MBMSGI01] bZ[W`ID[' + arg0 + ']̃pbP[Ww肳Ă܂B'
    #end

    def getMbmsgi02(self, arg0):
        """bZ[W`ID[BlancoMessage]AL[[MBMSGI02]̕擾܂B

        No.3:
        [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMbmsgi02]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return '[MBMSGI02] T|[gȂo̓vO~Oꏈn[' + arg0 + ']w肳܂B'
    #end

    def getMbmsgi03(self, arg0, arg1):
        """bZ[W`ID[BlancoMessage]AL[[MBMSGI03]̕擾܂B

        No.4:
        [bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        arg1 -- u{1}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMbmsgi03]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg1 is None:
            raise ValueError, "\bh[getMbmsgi03]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return '[MBMSGI03] bZ[W`ID[' + arg0 + ']ɂāAL[[' + arg1 + ']2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B'
    #end

    def getMbmsgi04(self, arg0, arg1, arg2, arg3):
        """bZ[W`ID[BlancoMessage]AL[[MBMSGI04]̕擾܂B

        No.5:
        [bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        arg1 -- u{1}̒lB
        arg2 -- u{2}̒lB
        arg3 -- u{3}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMbmsgi04]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg1 is None:
            raise ValueError, "\bh[getMbmsgi04]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg2 is None:
            raise ValueError, "\bh[getMbmsgi04]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end
        if arg3 is None:
            raise ValueError, "\bh[getMbmsgi04]̃p[^[arg3]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return '[MBMSGI04] bZ[W`ID[' + arg0 + ']ɂāAL[[' + arg1 + ']̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[' + arg2 + ']ƃ\[XohƂĔfꍇ̒ǔ[' + arg3 + ']ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB'
    #end

    def getMbmsga01(self, arg0):
        """bZ[W`ID[BlancoMessage]AL[[MBMSGA01]̕擾܂B

        No.8:
        [^fBNg[{0}]݂܂B]

        self -- ̃\bh܂ރNXgB
        arg0 -- u{0}̒lB
        return -- bZ[WB
        """
        if arg0 is None:
            raise ValueError, "\bh[getMbmsga01]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        return '[MBMSGA01] ^fBNg[' + arg0 + ']݂܂B'
    #end
#end
